@@ -4,6 +4,7 @@ import json
 import re
 import argparse
 import sys
+import warnings
 from pathlib import Path
 from parse_ecli import pattern
 
@@ -16,41 +17,42 @@ def match_ecli(ecli_string):
 
     ecli_string = ecli_string.upper().strip(' .:/()\n')
 
-    if (match := re.match(pattern.laender_compiled, ecli_string)) is not None:
+    if (match := re.fullmatch(pattern.laender_compiled, ecli_string)) is not None:
         decision = Decision_Other(ecli_string)
         decision.parse_ecli(match)
         return decision
 
-    elif (match := re.match(pattern.bgh_compiled, ecli_string)) is not None:
+    elif (match := re.fullmatch(pattern.bgh_compiled, ecli_string)) is not None:
         decision = Decision_BGH(ecli_string)
         decision.parse_ecli(match)
         return decision
-    elif (match := re.match(pattern.bverfg_compiled, ecli_string)) is not None:
+
+    elif (match := re.fullmatch(pattern.bverfg_compiled, ecli_string)) is not None:
         decision = Decision_BVerfG(ecli_string)
         decision.parse_ecli(match)
         return decision
 
-    elif (match := re.match(pattern.bverwg_compiled, ecli_string)) is not None:
+    elif (match := re.fullmatch(pattern.bverwg_compiled, ecli_string)) is not None:
         decision = Decision_BVerwG(ecli_string)
         decision.parse_ecli(match)
         return decision
 
-    elif (match := re.match(pattern.bag_compiled, ecli_string)) is not None:
+    elif (match := re.fullmatch(pattern.bag_compiled, ecli_string)) is not None:
         decision = Decision_BAG(ecli_string)
         decision.parse_ecli(match)
         return decision
 
-    elif (match := re.match(pattern.bsg_compiled, ecli_string)) is not None:
+    elif (match := re.fullmatch(pattern.bsg_compiled, ecli_string)) is not None:
         decision = Decision_BSG(ecli_string)
         decision.parse_ecli(match)
         return decision
 
-    elif (match := re.match(pattern.bfh_compiled, ecli_string)) is not None:
+    elif (match := re.fullmatch(pattern.bfh_compiled, ecli_string)) is not None:
         decision = Decision_BFH(ecli_string)
         decision.parse_ecli(match)
         return decision
 
-    elif (match := re.match(pattern.bpatg_compiled, ecli_string)) is not None:
+    elif (match := re.fullmatch(pattern.bpatg_compiled, ecli_string)) is not None:
         decision = Decision_BPatG(ecli_string)
         decision.parse_ecli(match)
         return decision
@@ -374,9 +376,12 @@ class Decision_BVerwG(Decision):
         self.court_data["decisiontype"][1] = self.loaded_data["bverwg_decisiontype"][match.group("type")]
         self.court_data["date"][1] = match.group("date")[0:2] + "." + match.group("date")[2:4] + "." + match.group("year")
         self.court_data["collision"][1] = super().check_collision(match.group("collision"))
+        azsuffix = super().check_azpart_empty(match.group("azsuffix"))
+        if azsuffix != "":
+            self.court_data["register_explain"][1] = "Rechtsschutz bei überlangen Gerichtsverfahren"
         try:
             azstring = (match.group("azbody") + " " + self.loaded_data["bverwg_az"][match.group("azreg")]
-                                            + " " + match.group("aznumber").lstrip("0") + "." + match.group("azyear"))
+                                            + " " + match.group("aznumber").lstrip("0") + "." + match.group("azyear") + " " + azsuffix)
             self.court_data["az"][1] = ' '.join(azstring.split())
             self.court_data["decision_explain"][1] = self.loaded_data["bverwg_explain"][match.group("azreg")]
         except KeyError as e:
@@ -545,12 +550,24 @@ class Decision_Other(Decision):
     def parse_ecli_az_ordentliche(self, match):
         if az_match := re.match(pattern.ordentliche_az, match.group("az"), flags=re.VERBOSE):
             azprefix = super().check_azpart_empty(az_match.group("azprefix"))
+            azprefix = " ".join(re.split(r'(\d+)', azprefix))
+            # Im Präfix werden Ziffern und Buchstaben getrennt, Beispiel: 2OLG in ECLI:DE:OLGBAMB:2018:1130.2OLG110SS89.18.00
             azbody = super().check_azpart_empty(az_match.group("azbody"))
             azbody_sta = super().check_azpart_empty(az_match.group("azbody_sta"))
             azreg_sta = super().check_azpart_empty(az_match.group("azreg_sta"))
             if azreg_sta != '':
                 azreg_sta = self.loaded_data["ordentliche_az"][azreg_sta]
+            
+            if azreg_sta != '':
+                azyear = super().check_azpart_empty(az_match.group("azyear1"))
+            else:
+                azyear = az_match.group("azyear")
             azsuffix = super().check_azpart_empty(az_match.group("azsuffix"))
+            if az_match.group("azseparator") == ".":
+                azsuffix = " ".join(re.split(r'(\d+)', azsuffix)) + "[...]"
+            elif az_match.group("azseparator") == "UND":
+                azsuffix = "und " + " ".join(re.split(r'(\d+)', azsuffix.replace(".","/"))) + "[...]"
+
             azreg = az_match.group("azreg")
 
             if azreg.replace(".","") in self.loaded_data["ordentliche_az"]:
@@ -574,11 +591,16 @@ class Decision_Other(Decision):
             else:
                 decision_explain = "Unbekanntes Registerzeichen!"
             az = (azprefix + " " + azbody + " " + azreg
-                    + " " + azbody_sta + " " + azreg_sta + " "  + az_match.group("aznumber").lstrip("0") + "/" + az_match.group("azyear")
-                    + " " + azsuffix).strip() # Strip bezieht sich auf den gesamten String, der az zugewiesen wird!
+                    + " " + azbody_sta + " " + azreg_sta + " "  + az_match.group("aznumber").lstrip("0") + "/" + azyear
+                    + " " + azsuffix).strip(" /") # Strip bezieht sich auf den gesamten String, der az zugewiesen wird!
             az = re.sub(r"\s\s+" , " ", az)
-
-
+            return az, decision_explain
+        elif az_match := re.match(pattern.ordentliche_az_register, match.group("az"), flags=re.VERBOSE):
+            # Für Registerentscheidungen, z.B. ECLI:DE:AGFREIB:2015:0427.PR700066.0A
+            azbody = super().check_azpart_empty(az_match.group("azbody"))
+            az = (azbody + " " + az_match.group("azreg") + " " + az_match.group("aznum")).strip()
+            az = re.sub(r"\s\s+" , " ", az)
+            decision_explain = self.loaded_data["ordentliche_explain"][az_match.group("azreg").replace(".","")]
             return az, decision_explain
         else:
             raise InValidAZError("Ungültiges Aktenzeichen!")
@@ -588,6 +610,8 @@ class Decision_Other(Decision):
         decision_explain = ''
         register_explain = ''
         if az_match := re.match(pattern.verwg_az, match.group("az"), flags=re.VERBOSE):
+            azbody = az_match.group("azbody")
+            azreg = az_match.group("azreg")
             azregister = super().check_azpart_empty(az_match.group("azregister"))
             if azregister != '':
                 azregister = "." + azregister
@@ -605,17 +629,24 @@ class Decision_Other(Decision):
             if azprefix != '':
                 azprefix = azprefix + " "
 
-            az = (azprefix + az_match.group("azbody") + " " + az_match.group("azreg") + " "
-                    + az_match.group("aznumber").lstrip("0") + "/" + az_match.group("azyear") + azhessen + azregister).strip()
-
             if "VGHH" in match.group("court"):
                     decision_explain = self.loaded_data["verwg_explain_hamburg"][az_match.group("azreg")]
             else:
                 if az_match.group("azreg") in self.loaded_data["verwg_explain"]:
                     decision_explain = self.loaded_data["verwg_explain"][az_match.group("azreg")]
+                elif azreg.startswith(("A", "B", "C", "D")) and azreg.replace(".","")[1:] in self.loaded_data["verwg_explain"]:
+                # Wenn dies zutrifft, haben wir es höchstwahrscheinlich mit einer Kammer mit alphanumerischer
+                # Bezeichnung zu tun wie ECLI:DE:VGGE:2013:0110.6A.L6.13A.00 (Kammer 6a)
+                    decision_explain = self.loaded_data["verwg_explain"][az_match.group("azreg").replace(".","")[1:]]
+                    azbody = azbody + azreg[0].lower()
+                    azreg = azreg.replace(".","")[1:]
                 else:
                     decision_explain = "Unbekanntes Registerzeichen!"
 
+
+            az = (azprefix + azbody + " " + azreg + " "
+                    + az_match.group("aznumber").lstrip("0") + "/" + az_match.group("azyear") + azhessen + azregister).strip()
+
             return az, decision_explain, register_explain
         else:
             raise InValidAZError("Ungültiges Aktenzeichen!")
@@ -686,8 +717,8 @@ class Decision_Other(Decision):
                 self.court_data["az"][1] = match.group("az")
         except (NoValidECLIError, InValidAZError, InValidCourtError) as e:
             if jurisdiction == "o":
-                self.court_data["az"][1], self.court_data["decision_explain"][1] = match.group("az"), ""
-                raise UnknownAZError("Aktenzeichen konnte nicht analysiert werden und wird unverändert aus ECLI übernommen")
+                self.court_data["az"][1], self.court_data["decision_explain"][1] = " ".join(re.split(r'(\d+)', match.group("az"))), ""
+                warnings.warn("Aktenzeichen konnte nicht analysiert werden und wird unverändert aus ECLI übernommen")
             else:
                 raise e
 
@@ -840,6 +871,9 @@ def commandline_mode(ecli_string, output_file, raw=False):
             my_decision.output_decision(raw)
     except (NoValidECLIError, InValidAZError, InValidCourtError) as e:
         exception_print(e)
+    except (UnknownAZError) as e:
+        print(e)
+        pass
 
 
 
@@ -859,7 +893,7 @@ def main_func():
                         help='Bei Angabe einer Input-Datei wird nicht nach ECLI gesucht, sondern jede Zeile als ECLI behandelt'))
     (parser.add_argument('-s', '--silent', action='store_true',
                         help='Unterdrückt Warnungen, wenn eine Datei zum Einlesen angegeben wurde'))
-    (parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.9.4'))
+    (parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.9.5'))
     args, args2 = parser.parse_known_args()
 
 
