@@ -40,10 +40,10 @@ bgh = r"""
     (?P<ecli>ECLI):
     (?P<country>DE):
     (?P<court>BGH):
-    (?P<year>(?:19|20)[0-9]{2}): # Jahresbereich eingeschränkt auf 1900-2000
+    (?P<year>19[5-9][0-9]|20[0-9]{2}): # Jahresbereich eingeschränkt auf ab 1950
     (?P<date>(?:0[1-9]|[12][0-9]|3[01])(?:0[1-9]|1[012])[0-9]{2}) # Datum TTMMJJ
     (?P<type>[UBVS]) # Urteil, Beschluss etc.
-    (?P<azbody>\d|[IVX]{,4}) # Senatsbezeichnung. Straf = arabische Ziffern, Zivil = Römisch. Kann auch fehlen (zB. Kartellsachen)
+    (?P<azbody>[1-6]|[IVX]{,4}) # Senatsbezeichnung. Straf = arabische Ziffern, Zivil = Römisch. Kann auch fehlen (zB. Kartellsachen)
     (?P<azreg>[.A-Z]{2,11}) # Registerzeichen. Klammern werden im ECLI als Punkte dargestellt
     (?P<aznumber>\d{1,4})\. # Eingangsnummer
     (?P<azyear>\d{2})\.
@@ -66,7 +66,7 @@ bpatg = r"""
 """
 
 bverwg = r"""
-     (?P<ecli>ECLI):
+    (?P<ecli>ECLI):
     (?P<country>DE):
     (?P<court>BVERWG):
     (?P<year>(?:19|20)[0-9]{2}):
@@ -76,7 +76,8 @@ bverwg = r"""
     (?P<azreg>[()A-Z]{1,11})
     (?P<aznumber>\d{1,4})\.
     (?P<azyear>\d{2})
-    (?P<azsuffix>D)?\.
+    (?P<azsuffix>D)? #Suffix bei überlangen Verfahren
+    (?(azsuffix)|\.) #Punkt entfällt bei Suffix, sonst zwingend
     (?P<collision>\d)\b
 """
 
@@ -130,7 +131,7 @@ laender = r"""
     (?P<court>\w{2,7}):
     (?P<year>(?:19|20)[0-9]{2}):
     (?P<date>(?:0[1-9]|1[012])(?:0[1-9]|[12][0-9]|3[01]))\.
-    (?P<az>[\dA-Z\.]{2,15}\.[\dA-Z]{1,15})\.
+    (?P<az>[\.\dA-Z]{4,17})\.
     (?P<collision>[\dA-Z]{2})\b
 """
 
@@ -156,14 +157,21 @@ ordentliche = r"""
 """
 
 ordentliche_az = r"""
-    (?P<azprefix>[A-Z]{1,4}?)?? # Optional und lazy, tritt daher hinter azreg zurück
+    (?P<azprefix>[\dA-Z]{1,4}?)??\.? # Optional und lazy, tritt daher hinter azreg zurück
     (?P<azbody>\d{1,3})?
-    (?P<azreg>[A-Z\.]{1,5})\.?
+    (?P<azreg>[A-Z\.]{1,7})\.?
     (?P<azbody_sta>\d{1,5}(?=JS))? # Matcht nur, wenn ein JS folgt.
     (?P<azreg_sta>JS)?
-    (?P<aznumber>\d{1,5})\.
-    (?P<azyear>\d{1,2})
-    (?P<azsuffix>[A-Z]{1,5})?
+    (?P<aznumber>\d{1,5})
+    (?(azreg_sta)\.?(?P<azyear1>\d{1,2})?\.?|\.(?P<azyear>\d{1,2})) #Wenn JS, dann ist der Punkt entbehrlich
+    (?P<azseparator>(\.|UND))?
+    (?P<azsuffix>[\.\dA-Z]{1,7})?$
+"""
+
+ordentliche_az_register = r""" # Für Handels-, Vereinsregister etc. 
+    (?P<azbody>\d{1,3})?
+    (?P<azreg>HR(A|B)?|PR|GN?R|PR|VR)
+    (?P<aznum>[\d]{1,8})$
 """
 
 sozg = r"""
@@ -185,7 +193,7 @@ arbg = r"""
 
 arbg_az = r"""
     ^(?P<azbody>\d{1,2})
-    (?P<azreg>[ARBVGHCNSTLO]{1,3})
+    (?P<azreg>[A-Z]{1,6})
     (?P<aznumber>\d{1,4})\.
     (?P<azyear>\w?\d{2})$
 """
@@ -197,11 +205,11 @@ verwg = r"""
 verwg_az = r"""
     (?P<azprefix>OVG)?
     (?P<azbody>\d{1,2})
-    (?P<azreg>[A-Z]{1,3})
+    (?P<azreg>[\.A-Z]{1,3})
     (?P<aznumber>\d{1,4})\.
     (?P<azyear>\d{2})($|\.?
     (?P<azhessen>F|KS|DA|GI|WI)?\.? # Hessischer Zusatz für das jeweilige Gericht, z.B. KS für Kassel
-    (?P<azregister>A|AK|EK|G|GR|NE|PVB|PVL|S|T|U)? # Registerzusatz z.B. A für Asyl
+    (?P<azregister>A|AK|BDG|EK|G|GR|NE|O|PVB|PVL|S|T|U)? # Registerzusatz z.B. A für Asyl
     $) # End of String in der zweiten Alternative wichtig, damit "33L2274.14" in "33L2274.14PB" nicht matcht
 """
 
